distribute/cluster/membership
Types
Values
pub fn current_leader() -> option.Option(String)
pub fn members_with_status() -> List(#(String, Status, Int))
Return the list of nodes and their status and incarnation according to the background poller.
Returns a list of tuples #(NodeName, Status, Incarnation).
pub fn metrics() -> List(#(String, Int))
Return internal metrics as a list of (name, value) tuples.
pub fn metrics_get(name: String) -> Int
pub fn start_service(interval_ms: Int) -> Nil
Start the background membership poller with interval in milliseconds.