distribute/crypto/sodium_adapter
Sodium adapter scaffold (not implemented).
This module provides the API structure for a future libsodium-backed adapter. The native libsodium implementation is NOT provided.
Use otp_crypto_adapter instead for a working crypto adapter based on
Erlang’s :crypto module.
This stub exists to reserve the module name and API for future native libsodium integration (using NIF with sodium_malloc/sodium_memzero/mlock).
Values
pub fn new() -> adapter.CryptoAdapter